searchData={"content_type":"text/markdown","items":[{"doc":"An Elixir/Erlang library providing low level operations for dealing with Emoji\nglyphs in the Unicode standard.\n\nExmoji is like a swiss-army knife for dealing with Emoji encoding issues. If\nall you need to do is translate `:poop:` into a smiling poop glyph, then there\nare plenty of other libs out there that will probably do what you want.  But\nonce you are dealing with Emoji as a fundamental part of your application, and\nyou start to realize the nightmare of doublebyte encoding or variants, then\nthis library may be your new best friend.","ref":"Exmoji.html","title":"Exmoji","type":"module"},{"doc":"Returns a list of all 845 Emoji characters as `EmojiChar`.","ref":"Exmoji.html#all/0","title":"Exmoji.all/0","type":"function"},{"doc":"Returns a list of all `EmojiChar` that are represented as doublebyte encoding.","ref":"Exmoji.html#all_doublebyte/0","title":"Exmoji.all_doublebyte/0","type":"function"},{"doc":"Returns a list of all `EmojiChar` that have at least one variant encoding.","ref":"Exmoji.html#all_with_variants/0","title":"Exmoji.all_with_variants/0","type":"function"},{"doc":"Convert a native bitstring glyph to its unified codepoint ID.\n\nThis is a conversion operation, not a match, so it may produce unexpected\nresults with different types of values.","ref":"Exmoji.html#char_to_unified/1","title":"Exmoji.char_to_unified/1","type":"function"},{"doc":"iex> Exmoji.char_to_unified(\"👾\")\n    \"1F47E\"\n\n    iex> Exmoji.char_to_unified(\"#️⃣\")\n    \"0023-FE0F-20E3\"","ref":"Exmoji.html#char_to_unified/1-examples","title":"Examples - Exmoji.char_to_unified/1","type":"function"},{"doc":"Returns a list of all known Emoji characters rendered as Unicode bitstrings.\n\nBy default, the default rendering options for this library will be used.\nHowever, if you pass the option of `include_variants: true` then all possible\nrenderings of a single glyph will be included, meaning that:\n\n1. You will have \"duplicate\" emojis in your list.\n2. This list is now suitable for exhaustably matching against in a search.","ref":"Exmoji.html#chars/1","title":"Exmoji.chars/1","type":"function"},{"doc":"Returns a list of all known codepoints representing Emoji characters.\n\nThis function also accepts the `include_variants` option, for details on its\nsignificance, see similar discussion for the `Exmoji.chars/1` function.","ref":"Exmoji.html#codepoints/1","title":"Exmoji.codepoints/1","type":"function"},{"doc":"Finds any `EmojiChar` that contains given string in its official name.","ref":"Exmoji.html#find_by_name/1","title":"Exmoji.find_by_name/1","type":"function"},{"doc":"iex> Exmoji.find_by_name \"father\"\n    [%Exmoji.EmojiChar{name: \"FATHER CHRISTMAS\", short_name: \"santa\",\n    short_names: [\"santa\"], text: nil, unified: \"1F385\", variations: []}]\n\n    iex> for t <- Exmoji.find_by_name(\"tree\"), do: t.name\n    [\"EVERGREEN TREE\", \"DECIDUOUS TREE\", \"PALM TREE\", \"CHRISTMAS TREE\",\n    \"TANABATA TREE\"]","ref":"Exmoji.html#find_by_name/1-examples","title":"Examples - Exmoji.find_by_name/1","type":"function"},{"doc":"Find all `EmojiChar` that match substring in any of their associated short\nname keywords.","ref":"Exmoji.html#find_by_short_name/1","title":"Exmoji.find_by_short_name/1","type":"function"},{"doc":"Finds an `EmojiChar` based on its short name keyword.\n\nCase insensitive. Otherwise must match exactly. Do not include the `:colon:`\nidentifiers if you are parsing text that uses them to indicate the presence of\na keyword.","ref":"Exmoji.html#from_short_name/1","title":"Exmoji.from_short_name/1","type":"function"},{"doc":"Finds a specific `EmojiChar` based on the unified codepoint ID.","ref":"Exmoji.html#from_unified/1","title":"Exmoji.from_unified/1","type":"function"},{"doc":"Convert a unified ID directly to its bitstring glyph representation.","ref":"Exmoji.html#unified_to_char/1","title":"Exmoji.unified_to_char/1","type":"function"},{"doc":"iex> Exmoji.unified_to_char(\"1F47E\")\n    \"👾\"","ref":"Exmoji.html#unified_to_char/1-example","title":"Example - Exmoji.unified_to_char/1","type":"function"},{"doc":"EmojiChar is a struct represents a single Emoji character and its associated\nmetadata.","ref":"Exmoji.EmojiChar.html","title":"Exmoji.EmojiChar","type":"module"},{"doc":"* `name` - The standardized name used in the Unicode specification to\n  represent this emoji character.\n* `unified` - The primary unified codepoint ID for the emoji.\n* `variations` - A list of all variant codepoints that may also represent this\n  emoji.\n* `short_name` - The canonical \"short name\" or keyword used in many systems to\n  refer to this emoji. Often surrounded by `:colons:` in systems like GitHub\n  & Campfire.\n* `short_names` - A full list of possible keywords for the emoji.\n* `text` - An alternate textual representation of the emoji, for example a\n  smiley face emoji may be represented with an ASCII alternative. Most emoji\n  do not have a text alternative. This is typically used when building an\n  automatic translation from typed emoticons.\n\nIt also contains a few helper functions to deal with this data type.","ref":"Exmoji.EmojiChar.html#module-fields","title":"Fields - Exmoji.EmojiChar","type":"module"},{"doc":"Returns a list of all possible bitstring renderings of an `EmojiChar`.\n\nE.g., normal, with variant selectors, etc. This is useful if you want to have\nall possible values to match against when searching for the emoji in a string\nrepresentation.","ref":"Exmoji.EmojiChar.html#chars/1","title":"Exmoji.EmojiChar.chars/1","type":"function"},{"doc":"Returns a list of all possible codepoint string IDs of an `EmojiChar`.\n\nE.g., normal, with variant selectors, etc. This is useful if you want to have\nall possible values to match against.","ref":"Exmoji.EmojiChar.html#codepoint_ids/1","title":"Exmoji.EmojiChar.codepoint_ids/1","type":"function"},{"doc":"iex> Exmoji.from_short_name(\"cloud\") |> Exmoji.EmojiChar.codepoint_ids\n    [\"2601\",\"2601-FE0F\"]","ref":"Exmoji.EmojiChar.html#codepoint_ids/1-example","title":"Example - Exmoji.EmojiChar.codepoint_ids/1","type":"function"},{"doc":"Is the `EmojiChar` represented by a doublebyte codepoint in Unicode?","ref":"Exmoji.EmojiChar.html#doublebyte?/1","title":"Exmoji.EmojiChar.doublebyte?/1","type":"function"},{"doc":"Renders an `EmojiChar` to its bitstring glyph representation, suitable for\nprinting to screen.\n\nBy passing options field `variant_encoding` you can manually specify whether\nthe variant encoding selector should be used to hint to rendering devices\nthat \"graphic\" representation should be used. By default, we use this for all\nEmoji characters that contain a possible variant.","ref":"Exmoji.EmojiChar.html#render/2","title":"Exmoji.EmojiChar.render/2","type":"function"},{"doc":"Returns the most likely variant-encoding codepoint ID for an `EmojiChar`.\n\nFor now we only know of one possible variant encoding for certain characters,\nbut there could be others in the future.\n\nThis is typically used to force Emoji rendering for characters that could be\nrepresented in standard font glyphs on certain operating systems.\n\nThe resulting encoded string will be two codepoints, or three codepoints for\ndoublebyte Emoji characters.\n\nIf there is no variant-encoding for a character, returns nil.","ref":"Exmoji.EmojiChar.html#variant/1","title":"Exmoji.EmojiChar.variant/1","type":"function"},{"doc":"Does the `EmojiChar` have an alternate Unicode variant encoding?","ref":"Exmoji.EmojiChar.html#variant?/1","title":"Exmoji.EmojiChar.variant?/1","type":"function"},{"doc":"Provides fast searches against binary strings for the presence of UTF-8\nencoded Emoji characters.","ref":"Exmoji.Scanner.html","title":"Exmoji.Scanner","type":"module"},{"doc":"Scans a bitstring for all encoded emoji characters contained within.\n\nReturns a list of all `EmojiChar` contained within that string, in order.","ref":"Exmoji.Scanner.html#scan/1","title":"Exmoji.Scanner.scan/1","type":"function"},{"doc":"iex> Exmoji.Scanner.scan(\"flying on my 🚀 to visit the 👾 people.\")\n    [%Exmoji.EmojiChar{name: \"ROCKET\", short_name: \"rocket\",\n      short_names: [\"rocket\"], text: nil, unified: \"1F680\", variations: []},\n     %Exmoji.EmojiChar{name: \"ALIEN MONSTER\", short_name: \"space_invader\",\n      short_names: [\"space_invader\"], text: nil, unified: \"1F47E\", variations: []}]","ref":"Exmoji.Scanner.html#scan/1-example","title":"Example - Exmoji.Scanner.scan/1","type":"function"},{"doc":"# The MIT License (MIT)\n\nCopyright (c) 2014 Matthew Rothenberg\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"Exmoji\n======\n\n[![Build Status](https://travis-ci.org/mroth/exmoji.svg?branch=master)](https://travis-ci.org/mroth/exmoji)\n[![Module Version](https://img.shields.io/hexpm/v/exmoji.svg)](https://hex.pm/packages/exmoji)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/exmoji/)\n[![Total Download](https://img.shields.io/hexpm/dt/exmoji.svg)](https://hex.pm/packages/exmoji)\n[![License](https://img.shields.io/hexpm/l/exmoji.svg)](https://github.com/mroth/exmoji/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/mroth/exmoji.svg)](https://github.com/mroth/exmoji/commits/master)\n\nAn Elixir/Erlang library providing low level operations for dealing with Emoji\nglyphs in the Unicode standard. :cool:\n\nExmoji is like a swiss-army knife for dealing with Emoji encoding issues. If all\nyou need to do is translate `:poop:` into :poop:, then there are plenty of other\nlibs out there that will probably do what you want.  But once you are dealing\nwith Emoji as a fundamental part of your application, and you start to realize\nthe nightmare of [doublebyte encoding][doublebyte] or [variants][variant], then\nthis library may be your new best friend. :raised_hands:\n\nExmoji is written by the same author as the Ruby [emoji_data.rb][rb] gem, which\nis used in production by [Emojitracker.com][emojitracker] to parse well over\n100M+ emoji glyphs daily. This version was written to provide all the same\nfunctionality while being even higher performance. :dizzy:\n\n[doublebyte]: http://www.quora.com/Why-does-using-emoji-reduce-my-SMS-character-limit-to-70\n[variant]: http://www.unicode.org/L2/L2011/11438-emoji-var.pdf\n[rb]: https://github.com/mroth/emoji_data.rb\n[emojitracker]: http://www.emojitracker.com\n\nInstallation\n------------\n\nAdd it to your deps list in your `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:exmoji, \"~> 0.3.0\"}\n  ]\nend\n```\n\nTo get the development version, you can pull directly from GitHub:\n\n```elixir\ndefp deps do\n  [\n    {:exmoji, github: \"mroth/exmoji\"}\n  ]\nend\n```\n\n\nModules\n-------\nFull API documentation is available via standard module docs or here:\nhttps://mroth.github.io/exmoji/\n\n\n##","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"The main library, with detailed search and conversion functions.\n\nSome examples:\n\n```elixir\niex> Exmoji.from_unified \"0023-20E3\"\n%Exmoji.EmojiChar{name: \"HASH KEY\", short_name: \"hash\", short_names: [\"hash\"],\n text: nil, unified: \"0023-20E3\", variations: [\"0023-FE0F-20E3\"]}\n\niex> Exmoji.all |> Enum.count\n845\n\niex> Exmoji.all_with_variants |> Enum.count\n107\n\niex> Exmoji.find_by_short_name(\"moon\") |> Enum.count\n13\n\niex> for t <- Exmoji.find_by_name(\"tree\"), do: t.name\n[\"EVERGREEN TREE\", \"DECIDUOUS TREE\", \"PALM TREE\", \"CHRISTMAS TREE\",\n\"TANABATA TREE\"]\n```\n\n##","ref":"readme.html#exmoji","title":"Exmoji - Overview","type":"extras"},{"doc":"A struct representation of a single Emoji character and all of its\nassociated metadata.\n\nThis module also contains some convenience methods for acting upon these\nstructs. For example, `EmojiChar.render/1` will produce a bitstring\nrepresentation of an Emoji character suitable for transmission.  It understands\nwhich Emoji have variant encodings and will do the right thing to make sure they\nare likely to display correctly on the other end.\n\n```elixir\niex> alias Exmoji.EmojiChar\nnil\n\niex> for e <- Exmoji.all, EmojiChar.doublebyte?(e), do: e.short_name\n[\"hash\", \"zero\", \"one\", \"two\", \"three\", \"four\", \"five\", \"six\", \"seven\", \"eight\",\n \"nine\", \"cn\", \"de\", \"es\", \"fr\", \"gb\", \"it\", \"jp\", \"kr\", \"ru\", \"us\"]\n\niex> for m <- Exmoji.find_by_short_name(\"moon\"), do: EmojiChar.render(m)\n[\"🌑\", \"🌒\", \"🌓\", \"🌔\", \"🌕\", \"🌖\", \"🌗\", \"🌘\", \"🌙\", \"🌚\", \"🌛\", \"🌜\", \"🌝\"]\n\n```\n\n##","ref":"readme.html#exmoji-emojichar","title":"Exmoji.EmojiChar - Overview","type":"extras"},{"doc":"Provides very fast searches against binary strings for the presence of UTF-8\nencoded Emoji glyphs.  Whereas the Ruby and NodeJS versions of this library\naccomplish this via regular expressions, the Elixir version relies on optimized\nbinary pattern matching, making it faster.\n\nAn example:\n\n```elixir\niex> for ec <- Exmoji.Scanner.scan(\"I ♥ when marketers talk about the ☁.\") do\n...>   IO.puts \"Found some #{ec.short_name}!\"\n...> end\nFound some hearts!\nFound some cloud!\n[:ok, :ok]\n\n```","ref":"readme.html#exmoji-scanner","title":"Exmoji.Scanner - Overview","type":"extras"},{"doc":"Please be sure to run `mix test` and help keep test coverage at :100:. (Note:\n_excoveralls_ is currently lying, actual test coverage is 100%, but it\ndoesn't seem to catch dynamically defined functions. Do `mix coveralls.details`\nand manually verify those for now.)\n\nThere is a full benchmark suite available via `mix bench`.  Please\nrun before and after your changes to ensure you have not caused a performance\nregression.","ref":"readme.html#contributing","title":"Contributing - Overview","type":"extras"},{"doc":"Copyright (c) 2014 Matthew Rothenberg\n\nThis work is free. You can redistribute it and/or modify it under the\nterms of the MIT License. See the [LICENSE.md](./LICENSE.md) file for more details.","ref":"readme.html#copyright-and-license","title":"Copyright and License - Overview","type":"extras"}]}